@@ -48,6 +48,16 @@ public class ParameterFinder
          */
         public final static Query BPD_PINTAN_ORDERHASHMODE = new Query("Params_*.TAN2StepPar{0}.ParTAN2Step*.orderhashmode",true);
 
+        /**
+         * Die 3 verschiedenen Parameter für status refresh requests beim Decoupled Verfahren:
+         *  1. Minimale Zeit vor dem ersten refresh (Sekunden).
+         *  2. Minimale Zeit vor weiteren refreshes (Sekunden).
+         *  3. Maximale Anzahl von refreshes.
+         */
+        public final static Query BPD_DECOUPLED_TIME_BEFORE_FIRST_STATUS_REQUEST = new Query("Params_*.TAN2StepPar*.ParTAN2Step*.TAN2StepParams_*.decoupled_time_before_first_status_request",false);
+        public final static Query BPD_DECOUPLED_TIME_BEFORE_NEXT_STATUS_REQUEST = new Query("Params_*.TAN2StepPar*.ParTAN2Step*.TAN2StepParams_*.decoupled_time_before_next_status_request",false);
+        public final static Query BPD_DECOUPLED_MAX_STATUS_REQUESTS = new Query("Params_*.TAN2StepPar*.ParTAN2Step*.TAN2StepParams_*.decoupled_max_status_requests",false);
+
         private String query = null;
         private boolean paramsSet = false;
         
